﻿#include "messagebox.h"
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QApplication>
#include <QDesktopWidget>
#include <QFile>
#include <QEvent>
#include <QTextStream>
namespace KInstaller {
MessageBox::MessageBox(QDialog *parent) : QDialog(parent)
{
    this->setObjectName("MessageBox");
    this->setMaximumSize(540, 164);
    this->setMinimumSize(424, 164);
    QPixmap pixmap = QPixmap(":/data/png/bg_message.jpg");
    QPalette pal(this->palette());
    pal.setBrush(backgroundRole(), QBrush(pixmap));
    this->setAutoFillBackground(true);
    this->setPalette(pal);

    this->setWindowModality(Qt::ApplicationModal);
    this->setAttribute(Qt::WA_ShowModal, true);
    setWindowFlags(Qt::FramelessWindowHint |
                   Qt::WindowStaysOnTopHint |
                   Qt::WindowDoesNotAcceptFocus |
                   Qt::Dialog);

    initUI();
    addStyleSheet();
    initAllConnect();
    translateStr();

}

void MessageBox::initUI()
{
    QVBoxLayout* vlayout = new QVBoxLayout;
    vlayout->setContentsMargins(24, 4, 4, 24);
    this->setLayout(vlayout);
    vlayout->setSpacing(4);
    QHBoxLayout* hlayout = new QHBoxLayout;


    m_close = new QPushButton;
    m_close->setObjectName("close");
    m_close->setFlat(true);
    m_close->setIcon(QIcon(":/data/svg/close.svg"));
    m_close->setIconSize(QSize(36, 36));

    m_info = new QLabel;
    m_info->setObjectName("info");

    hlayout->addSpacerItem(new QSpacerItem(4, 4, QSizePolicy::Expanding, QSizePolicy::Expanding));
    hlayout->addWidget(m_close);
    vlayout->addLayout(hlayout);

    QHBoxLayout *hlayout1 = new QHBoxLayout;
    QLabel *label = new QLabel;

    //添加svg图片，并设置其大小
    label->setPixmap(QPixmap(QIcon(":/data/svg/tip.svg").pixmap(QSize(24, 24))));
    hlayout1->addWidget(label);
    hlayout1->addWidget(m_info, Qt::AlignLeft | Qt::AlignTop);
    hlayout1->addSpacerItem(new QSpacerItem(24, 4, QSizePolicy::Fixed, QSizePolicy::Preferred));
    vlayout->addLayout(hlayout1, Qt::AlignLeft | Qt::AlignTop);


    QHBoxLayout *hlayout2 = new QHBoxLayout;
    hlayout2->addStretch();
    m_cancel = new QPushButton;
    m_cancel->setObjectName("cancel");
    hlayout2->addWidget(m_cancel);


    m_OK = new QPushButton;
    m_OK->setObjectName("OK");

    hlayout2->addWidget(m_OK);
    hlayout2->addSpacerItem(new QSpacerItem(24, 4, QSizePolicy::Fixed, QSizePolicy::Preferred));
    vlayout->addLayout(hlayout2, Qt::AlignLeft);

}

void MessageBox::initAllConnect()
{
    connect(m_close, &QPushButton::clicked, [=]{execid = 1;reject();});
    connect(m_cancel, &QPushButton::clicked, [=]{ execid = 1;
        reject();
//            this->close();
    });
    connect(m_OK, &QPushButton::clicked, [=]{
        execid = 1;
        accept();
//        this->close();
    });
}


void MessageBox::addStyleSheet()
{
    QFile file(":/data/qss/MessageBox.css");
    file.open(QFile::ReadOnly);
    QTextStream filetext(&file);
    QString stylesheet = filetext.readAll();
    file.close();

    this->setStyleSheet(stylesheet);
}


void MessageBox::translateStr()
{
//    m_title->setText(tr("Close"));
    m_cancel->setText(tr("Cancel"));
    m_OK->setText(tr("OK"));
//    m_info->setText(tr("the installer is about to exit and the computer will be shut down."));
}
void MessageBox::changeEvent(QEvent *event)
{
    if (event->type() == QEvent::LanguageChange) {
        translateStr();
    } else {
        QWidget::changeEvent(event);
    }
}

void MessageBox::resizeEvent(QResizeEvent *event)
{
//    InstallerMainWidget::resizeEvent(event);
    // Your code here
    QRect screenRect = QApplication::desktop()->screenGeometry();

    this->move(screenRect.width() / 2 - this->width() / 2, screenRect.height() / 2 - this->height() / 2);
}

void MessageBox::setMessageInfo(QString info)
{
    m_info->setText(info);
    m_info->adjustSize();
}
void MessageBox::setCancleHidden()
{
    m_cancel->setHidden(true);
    m_cancel->setEnabled(false);
}


}

